<?php

namespace Survey\Question\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Survey\Question\Http\Requests\RoptionRequest;
use Survey\Question\Interfaces\RoptionRepositoryInterface;
use Survey\Question\Models\Roption;
use Survey\Question\Forms\Roption as Form;

/**
 * APIController  class for roption.
 */
class RoptionAPIController extends BaseController
{

    /**
     * Initialize roption resource controller.
     *
     * @param type RoptionRepositoryInterface $roption
     *
     * @return null
     */
    public function __construct(RoptionRepositoryInterface $roption)
    {
        parent::__construct();
        $this->repository = $roption;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Survey\Question\Repositories\Criteria\RoptionResourceCriteria::class);
    }

    /**
     * Display a list of roption.
     *
     * @return Response
     */
    public function index(RoptionRequest $request)
    {
        return $this->repository
            ->setPresenter(\Survey\Question\Repositories\Presenter\RoptionPresenter::class)
            ->paginate();
    }

    /**
     * Display roption.
     *
     * @param Request $request
     * @param Model   $roption
     *
     * @return Response
     */
    public function show(RoptionRequest $request, Roption $roption)
    {
        return $roption->setPresenter(\Survey\Question\Repositories\Presenter\RoptionListPresenter::class);
        ;
    }

    /**
     * Create new roption.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(RoptionRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('question::roption.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('question/roption/' . $roption->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('question/roption');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the roption.
     *
     * @param Request $request
     * @param Model   $roption
     *
     * @return Response
     */
    public function update(RoptionRequest $request, Roption $roption)
    {
        try {
            $data = $request->all();

            $roption->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('question::roption.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('question/roption/' . $roption->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('question/roption/' . $roption->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the roption.
     *
     * @param Model   $roption
     *
     * @return Response
     */
    public function destroy(RoptionRequest $request, Roption $roption)
    {
        try {
            $roption->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('question::roption.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('question/roption/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('question/roption/' . $roption->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
