<?php

namespace Survey\Question\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Survey\Question\Http\Requests\TemplateRequest;
use Survey\Question\Interfaces\TemplateRepositoryInterface;
use Survey\Question\Models\Template;
use Survey\Question\Forms\Template as Form;

/**
 * APIController  class for template.
 */
class TemplateAPIController extends BaseController
{

    /**
     * Initialize template resource controller.
     *
     * @param type TemplateRepositoryInterface $template
     *
     * @return null
     */
    public function __construct(TemplateRepositoryInterface $template)
    {
        parent::__construct();
        $this->repository = $template;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Survey\Question\Repositories\Criteria\TemplateResourceCriteria::class);
    }

    /**
     * Display a list of template.
     *
     * @return Response
     */
    public function index(TemplateRequest $request)
    {
        return $this->repository
            ->setPresenter(\Survey\Question\Repositories\Presenter\TemplatePresenter::class)
            ->paginate();
    }

    /**
     * Display template.
     *
     * @param Request $request
     * @param Model   $template
     *
     * @return Response
     */
    public function show(TemplateRequest $request, Template $template)
    {
        return $template->setPresenter(\Survey\Question\Repositories\Presenter\TemplateListPresenter::class);
        ;
    }

    /**
     * Create new template.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(TemplateRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('question::template.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('question/template/' . $template->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('question/template');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the template.
     *
     * @param Request $request
     * @param Model   $template
     *
     * @return Response
     */
    public function update(TemplateRequest $request, Template $template)
    {
        try {
            $data = $request->all();

            $template->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('question::template.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('question/template/' . $template->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('question/template/' . $template->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the template.
     *
     * @param Model   $template
     *
     * @return Response
     */
    public function destroy(TemplateRequest $request, Template $template)
    {
        try {
            $template->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('question::template.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('question/template/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('question/template/' . $template->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
