<?php

namespace Survey\Question\Policies;

use Litepie\User\Contracts\UserPolicy;
use Survey\Question\Models\Dimension;

class DimensionPolicy
{

    /**
     * Determine if the given user can view the dimension.
     *
     * @param UserPolicy $user
     * @param Dimension $dimension
     *
     * @return bool
     */
    public function view(UserPolicy $user, Dimension $dimension)
    {
        if ($user->canDo('question.dimension.view') && $user->isAdmin()) {
            return true;
        }

        return $dimension->user_id == user_id() && $dimension->user_type == user_type();
    }

    /**
     * Determine if the given user can create a dimension.
     *
     * @param UserPolicy $user
     * @param Dimension $dimension
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('question.dimension.create');
    }

    /**
     * Determine if the given user can update the given dimension.
     *
     * @param UserPolicy $user
     * @param Dimension $dimension
     *
     * @return bool
     */
    public function update(UserPolicy $user, Dimension $dimension)
    {
        if ($user->canDo('question.dimension.edit') && $user->isAdmin()) {
            return true;
        }

        return $dimension->user_id == user_id() && $dimension->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given dimension.
     *
     * @param UserPolicy $user
     * @param Dimension $dimension
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Dimension $dimension)
    {
        return $dimension->user_id == user_id() && $dimension->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given dimension.
     *
     * @param UserPolicy $user
     * @param Dimension $dimension
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Dimension $dimension)
    {
        if ($user->canDo('question.dimension.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given dimension.
     *
     * @param UserPolicy $user
     * @param Dimension $dimension
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Dimension $dimension)
    {
        if ($user->canDo('question.dimension.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
