<?php

namespace Survey\Question\Policies;

use Litepie\User\Contracts\UserPolicy;
use Survey\Question\Models\Roption;

class RoptionPolicy
{

    /**
     * Determine if the given user can view the roption.
     *
     * @param UserPolicy $user
     * @param Roption $roption
     *
     * @return bool
     */
    public function view(UserPolicy $user, Roption $roption)
    {
        if ($user->canDo('question.roption.view') && $user->isAdmin()) {
            return true;
        }

        return $roption->user_id == user_id() && $roption->user_type == user_type();
    }

    /**
     * Determine if the given user can create a roption.
     *
     * @param UserPolicy $user
     * @param Roption $roption
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('question.roption.create');
    }

    /**
     * Determine if the given user can update the given roption.
     *
     * @param UserPolicy $user
     * @param Roption $roption
     *
     * @return bool
     */
    public function update(UserPolicy $user, Roption $roption)
    {
        if ($user->canDo('question.roption.edit') && $user->isAdmin()) {
            return true;
        }

        return $roption->user_id == user_id() && $roption->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given roption.
     *
     * @param UserPolicy $user
     * @param Roption $roption
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Roption $roption)
    {
        return $roption->user_id == user_id() && $roption->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given roption.
     *
     * @param UserPolicy $user
     * @param Roption $roption
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Roption $roption)
    {
        if ($user->canDo('question.roption.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given roption.
     *
     * @param UserPolicy $user
     * @param Roption $roption
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Roption $roption)
    {
        if ($user->canDo('question.roption.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
