<?php

namespace Survey\Question\Policies;

use Litepie\User\Contracts\UserPolicy;
use Survey\Question\Models\Template;

class TemplatePolicy
{

    /**
     * Determine if the given user can view the template.
     *
     * @param UserPolicy $user
     * @param Template $template
     *
     * @return bool
     */
    public function view(UserPolicy $user, Template $template)
    {
        if ($user->canDo('question.template.view') && $user->isAdmin()) {
            return true;
        }

        return $template->user_id == user_id() && $template->user_type == user_type();
    }

    /**
     * Determine if the given user can create a template.
     *
     * @param UserPolicy $user
     * @param Template $template
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('question.template.create');
    }

    /**
     * Determine if the given user can update the given template.
     *
     * @param UserPolicy $user
     * @param Template $template
     *
     * @return bool
     */
    public function update(UserPolicy $user, Template $template)
    {
        if ($user->canDo('question.template.edit') && $user->isAdmin()) {
            return true;
        }

        return $template->user_id == user_id() && $template->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given template.
     *
     * @param UserPolicy $user
     * @param Template $template
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Template $template)
    {
        return $template->user_id == user_id() && $template->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given template.
     *
     * @param UserPolicy $user
     * @param Template $template
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Template $template)
    {
        if ($user->canDo('question.template.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given template.
     *
     * @param UserPolicy $user
     * @param Template $template
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Template $template)
    {
        if ($user->canDo('question.template.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
