<?php

namespace Survey\Question\Providers;

use Illuminate\Support\ServiceProvider;

class QuestionServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'question');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'question');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerQuestion();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerQuestion()
    {
        $this->app->bind('question', function($app) {
            return new Question($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Question', 'Lavalite\Question\Facades\Question');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('survey.question', function ($app) {
            return $this->app->make('Survey\Question\Question');
        });

        // Bind Question to repository
        $this->app->bind(
            'Survey\Question\Interfaces\QuestionRepositoryInterface',
            \Survey\Question\Repositories\Eloquent\QuestionRepository::class
        );
        // Bind Dimension to repository
        $this->app->bind(
            'Survey\Question\Interfaces\DimensionRepositoryInterface',
            \Survey\Question\Repositories\Eloquent\DimensionRepository::class
        );
        // Bind Tag to repository
        $this->app->bind(
            'Survey\Question\Interfaces\TagRepositoryInterface',
            \Survey\Question\Repositories\Eloquent\TagRepository::class
        );
        // Bind Template to repository
        $this->app->bind(
            'Survey\Question\Interfaces\TemplateRepositoryInterface',
            \Survey\Question\Repositories\Eloquent\TemplateRepository::class
        );
        // Bind Roption to repository
        $this->app->bind(
            'Survey\Question\Interfaces\RoptionRepositoryInterface',
            \Survey\Question\Repositories\Eloquent\RoptionRepository::class
        );

        $this->app->register(\Survey\Question\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Survey\Question\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and question's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'survey.question'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeQuestion::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['survey.question'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('survey/question.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/question')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/question')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
